pub struct ConfigDetail {
pub file: String,
pub length_score: f64,
pub structure_score: f64,
pub specificity_score: f64,
pub actionable_score: f64,
pub file_refs_score: f64,
pub shell_commands_score: f64,
pub recency_score: f64,
pub llm_quality_score: Option<f64>,
}Fields
file: StringRelative path of the analyzed config file.
length_score: f64Score based on content length (chars).
structure_score: f64Score based on structural elements (headings, code blocks, lists).
specificity_score: f64Score based on project-specific terms, paths, and identifiers.
actionable_score: f64Score based on actionable keywords (MUST, NEVER, ALWAYS, etc.).
file_refs_score: f64Score based on whether referenced file paths actually exist.
shell_commands_score: f64Score based on presence of shell command code blocks.
recency_score: f64Score based on days since last modification.
llm_quality_score: Option<f64>LLM quality assessment score (0.0-1.0), None if LLM was not used.