pub struct EmbeddingClient { /* private fields */ }Expand description
Client for generating embeddings via Ollama.
Implementations
Sourceimpl EmbeddingClient
impl EmbeddingClient
Sourcepub async fn embed(&self, text: &str) -> Result<Vec<f32>, EmbeddingError>
pub async fn embed(&self, text: &str) -> Result<Vec<f32>, EmbeddingError>
Generate an embedding for a single text.
Sourcepub async fn embed_batch(
&self,
texts: &[&str],
) -> Result<Vec<Vec<f32>>, EmbeddingError>
pub async fn embed_batch( &self, texts: &[&str], ) -> Result<Vec<Vec<f32>>, EmbeddingError>
Generate embeddings for multiple texts in a single request.
Sourcepub async fn check_model_available(&self) -> bool
pub async fn check_model_available(&self) -> bool
Check if the embedding model is available in Ollama.