pub struct CouplingDetector;Expand description
Detects code-documentation coupling drift from git history.
Implementations
Sourceimpl CouplingDetector
impl CouplingDetector
Sourcepub fn detect(
doc_files: &[(String, Vec<String>)],
git_infos: &[GitFileInfo],
) -> Vec<CouplingIssue>
pub fn detect( doc_files: &[(String, Vec<String>)], git_infos: &[GitFileInfo], ) -> Vec<CouplingIssue>
Detect code-doc coupling issues.
Given a list of doc files and their referenced code paths, check if any code file changed more recently than the doc.
doc_files: slice of (doc_path, referenced_code_paths)
git_infos: git metadata for all relevant files